<?php

namespace Bixo\Photorequest\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\Photorequest\Forms\Photorequest as PhotorequestForm;
use Bixo\Photorequest\Http\Requests\PhotorequestResourceRequest;
use Bixo\Photorequest\Http\Resources\PhotorequestResource;
use Bixo\Photorequest\Http\Resources\PhotorequestsCollection;
use Bixo\Photorequest\Models\Photorequest;
use Bixo\Photorequest\Actions\PhotorequestAction;
use Bixo\Photorequest\Actions\PhotorequestActions;


/**
 * Resource controller class for photorequest.
 */
class PhotorequestResourceController extends BaseController
{

    /**
     * Initialize photorequest resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = PhotorequestForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.photorequest.modules'), 'photorequest', guard_url('photorequest'));
            return $next($request);
        });
    }

    /**
     * Display a list of photorequest.
     *
     * @return Response
     */
    public function index(PhotorequestResourceRequest $request)
    {
        $request = $request->all();
        $page = PhotorequestActions::run('paginate', $request);

        $data = new PhotorequestsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('photorequest::photorequest.names'))
            ->view('photorequest::photorequest.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display photorequest.
     *
     * @param Request $request
     * @param Model   $photorequest
     *
     * @return Response
     */
    public function show(PhotorequestResourceRequest $request, Photorequest $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new PhotorequestResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('photorequest::photorequest.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('photorequest::photorequest.show')
            ->output();
    }

    /**
     * Show the form for creating a new photorequest.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PhotorequestResourceRequest $request, Photorequest $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new PhotorequestResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('photorequest::photorequest.name'))
            ->view('photorequest::photorequest.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new photorequest.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PhotorequestResourceRequest $request, Photorequest $model)
    {
        try {
            $request = $request->all();
            $model = PhotorequestAction::run('store', $model, $request);
            $data = new PhotorequestResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('photorequest::photorequest.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('photorequest/photorequest/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/photorequest/photorequest'))
                ->redirect();
        }

    }

    /**
     * Show photorequest for editing.
     *
     * @param Request $request
     * @param Model   $photorequest
     *
     * @return Response
     */
    public function edit(PhotorequestResourceRequest $request, Photorequest $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new PhotorequestResource($model);
        // return view('photorequest::photorequest.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('photorequest::photorequest.name'))
            ->view('photorequest::photorequest.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the photorequest.
     *
     * @param Request $request
     * @param Model   $photorequest
     *
     * @return Response
     */
    public function update(PhotorequestResourceRequest $request, Photorequest $model)
    {
        try {
            $request = $request->all();
            $model = PhotorequestAction::run('update', $model, $request);
            $data = new PhotorequestResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('photorequest::photorequest.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('photorequest/photorequest/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('photorequest/photorequest/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the photorequest.
     *
     * @param Model   $photorequest
     *
     * @return Response
     */
    public function destroy(PhotorequestResourceRequest $request, Photorequest $model)
    {
        try {

            $request = $request->all();
            $model = PhotorequestAction::run('destroy', $model, $request);
            $data = new PhotorequestResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('photorequest::photorequest.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('photorequest/photorequest/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('photorequest/photorequest/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
