<?php

namespace Bixo\Photorequest\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Photorequest\Events\PhotorequestWorkflow as PhotorequestWorkflowEvent;
use Bixo\Photorequest\Notifications\PhotorequestWorkflow as PhotorequestWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class PhotorequestWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(PhotorequestWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $photorequest is submitted.
     *
     * @param PhotorequestWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(PhotorequestWorkflowEvent $event)
    {
        $client = $event->photorequest->client;
        Notification::send($client, new PhotorequestWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $photorequest is published.
     *
     * @param PhotorequestWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(PhotorequestWorkflowEvent $event)
    {
        $client = $event->photorequest->client;
        Notification::send($client, new PhotorequestWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $photorequest is approved.
     *
     * @param PhotorequestWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(PhotorequestWorkflowEvent $event)
    {
        $client = $event->photorequest->client;
        Notification::send($client, new PhotorequestWorkflowNotification($event));
    }

    /**
     * Handles the $photorequest workflow event as a listener.
     *
     * @param PhotorequestWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(PhotorequestWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
