<?php

namespace Bixo\Photorequest\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Photorequest\Models\Photorequest;

class PhotorequestPolicy
{

    use PhotorequestWorkflow;

    /**
     * Determine if the given user can view the photorequest.
     *
     * @param Authenticatable $user
     * @param Photorequest $photorequest
     *
     * @return bool
     */
    public function view(Authenticatable $user, Photorequest $photorequest)
    {
        if ($authUser->canDo('photorequest.photorequest.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $photorequest->is_owner;
    }

    /**
     * Determine if the given user can create a photorequest.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('photorequest.photorequest.create');
    }

    /**
     * Determine if the given user can update the given photorequest.
     *
     * @param Authenticatable $user
     * @param Photorequest $photorequest
     *
     * @return bool
     */
    public function update(Authenticatable $user, Photorequest $photorequest)
    {
        if ($user->canDo('photorequest.photorequest.edit') && $user->isAdmin()) {
            return true;
        }

        return $photorequest->is_owner;
    }

    /**
     * Determine if the given user can delete the given photorequest.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Photorequest $photorequest)
    {
        return $photorequest->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
